[![Release](https://img.shields.io/github/v/release/biosimulators/biosim-registry)](https://img.shields.io/github/v/release/biosimulators/bsedic)
[![Build status](https://img.shields.io/github/actions/workflow/status/biosimulators/biosim-registry/main.yml?branch=main)](https://github.com/biosimulators/biosim-registry/actions/workflows/main.yml?query=branch%3Amain)
[![codecov](https://codecov.io/gh/biosimulators/biosim-registry/branch/main/graph/badge.svg)](https://codecov.io/gh/biosimulators/biosim-registry)
[![License](https://img.shields.io/github/license/biosimulators/biosim-registry)](https://img.shields.io/github/license/biosimulators/biosim-registry)

# BioSimulations Registry
A repository filled with high quality processes, steps, and composites for process bi-graph.
All used as a standard library for process bi-graph.


- **Github repository**: <https://github.com/biosimulators/biosim-registry/>
- **Documentation** <https://biosimulators.github.io/biosim-registry/>

---

Repository initiated with [fpgmaas/cookiecutter-uv](https://github.com/fpgmaas/cookiecutter-uv).
